@@ -14,9 +14,6 @@
 /* Enable debugging info */
 #define DEBUG
 
-/* Does your version of PGP support the PGPPASSFD environment variable? */
-#define HAVE_PGPPASSFD
-
 /* What is your domain name? */
 #undef DOMAIN
 
@@ -71,26 +68,8 @@
 /* Where to find sendmail on your system */
 #undef SENDMAIL
 
-/* Where is PGP located on your system? */
-#undef _PGPPATH
-
-/* Where is PGP 2.* located on your system? */
-#undef _PGPV2PATH
-
-/* Where is PGP 5 located on your system? */
-#undef _PGPV3PATH
-
-/* Where is GNU Privacy Guard located on your system? */
-#undef _PGPGPGPATH
-
-/* Do we have PGP 2.*? */
-#undef HAVE_PGP2
-
-/* Do we have PGP 5.0 or up? */
-#undef HAVE_PGP5
-
-/* Do we have GPG? */
-#undef HAVE_GPG
+/* Do you want PGP support (--enable-pgp)? */
+#undef HAVE_PGP
 
 /* Where to find ispell on your system? */
 #undef ISPELL
