@@ -28,7 +28,7 @@
 #include "copy.h"
 #include "mx.h"
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 #include "pgp.h"
 #endif
 
@@ -377,10 +377,10 @@ int mutt_view_attachment (FILE *fp, BODY *a, int flag, HEADER *hdr,
   int unlink_tempfile = 0;
   
   is_message = mutt_is_message_type(a->type, a->subtype);
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
   if (is_message && a->hdr && (a->hdr->pgp & PGPENCRYPT) && !pgp_valid_passphrase())
     return (rc);
-#endif /* _PGPPATH */
+#endif /* HAVE_PGP */
   use_mailcap = (flag == M_MAILCAP ||
 		(flag == M_REGULAR && mutt_needs_mailcap (a)));
   snprintf (type, sizeof (type), "%s/%s", TYPE (a), a->subtype);
@@ -792,7 +792,7 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, char *path,
 
   if (s.fpout == NULL)
   {
-    perror ("fopen");
+    mutt_perror ("fopen");
     return (-1);
   }
 
@@ -804,14 +804,14 @@ int mutt_decode_save_attachment (FILE *fp, BODY *m, char *path,
 
     if (stat (m->filename, &st) == -1)
     {
-      perror ("stat");
+      mutt_perror ("stat");
       fclose (s.fpout);
       return (-1);
     }
 
     if ((s.fpin = fopen (m->filename, "r")) == NULL)
     {
-      perror ("fopen");
+      mutt_perror ("fopen");
       return (-1);
     }
 
