@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-8 Michael R. Elkins <me@cs.hmc.edu>
+ * Copyright (C) 1996-2000 Michael R. Elkins <me@cs.hmc.edu>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -40,9 +40,16 @@ static event_t *KeyEvent;
 
 void mutt_refresh (void)
 {
+  /* don't refresh when we are waiting for a child. */
+  if (option (OPTKEEPQUIET))
+    return;
+
   /* don't refresh in the middle of macros unless necessary */
-  if (!UngetCount || option (OPTFORCEREFRESH))
-    refresh ();
+  if (UngetCount && !option (OPTFORCEREFRESH))
+    return;
+
+  /* else */
+  refresh ();
 }
 
 event_t mutt_getch (void)
@@ -205,12 +212,15 @@ void mutt_curses_error (const char *fmt, ...)
   Errorbuf[ (COLS < sizeof (Errorbuf) ? COLS : sizeof (Errorbuf)) - 2 ] = 0;
   clean_error_buf();
 
-  BEEP ();
-  SETCOLOR (MT_COLOR_ERROR);
-  mvaddstr (LINES-1, 0, Errorbuf);
-  clrtoeol ();
-  SETCOLOR (MT_COLOR_NORMAL);
-  mutt_refresh ();
+  if (!option (OPTKEEPQUIET))
+  {
+    BEEP ();
+    SETCOLOR (MT_COLOR_ERROR);
+    mvaddstr (LINES-1, 0, Errorbuf);
+    clrtoeol ();
+    SETCOLOR (MT_COLOR_NORMAL);
+    mutt_refresh ();
+  }
 
   set_option (OPTMSGERR);
 }
@@ -226,17 +236,23 @@ void mutt_message (const char *fmt, ...)
   Errorbuf[ (COLS < sizeof (Errorbuf) ? COLS : sizeof (Errorbuf)) - 2 ] = 0;
   clean_error_buf();
 
-  SETCOLOR (MT_COLOR_MESSAGE);
-  mvaddstr (LINES - 1, 0, Errorbuf);
-  clrtoeol ();
-  SETCOLOR (MT_COLOR_NORMAL);
-  mutt_refresh ();
+  if (!option (OPTKEEPQUIET))
+  {
+    SETCOLOR (MT_COLOR_MESSAGE);
+    mvaddstr (LINES - 1, 0, Errorbuf);
+    clrtoeol ();
+    SETCOLOR (MT_COLOR_NORMAL);
+    mutt_refresh ();
+  }
 
   unset_option (OPTMSGERR);
 }
 
 void mutt_show_error (void)
 {
+  if (option (OPTKEEPQUIET))
+    return;
+  
   SETCOLOR (option (OPTMSGERR) ? MT_COLOR_ERROR : MT_COLOR_MESSAGE);
   CLEARLINE (LINES-1);
   addstr (Errorbuf);
@@ -247,23 +263,14 @@ void mutt_endwin (const char *msg)
 {
   if (!option (OPTNOCURSES))
   {
-#ifdef USE_SLANG_CURSES
     CLEARLINE (LINES - 1);
-    move (LINES - 1, 0)
-#else
-      move (LINES - 1, COLS - 1);
-    CLEARLINE (LINES - 1);
-#endif
     
     attrset (A_NORMAL);
     mutt_refresh ();
     endwin ();
-#ifndef USE_SLANG_CURSES
-    fputc ('\n', stdout);
-#endif
   }
   
-  if (msg)
+  if (msg && *msg)
     puts (msg);
 }
 
