@@ -43,11 +43,8 @@ int imap_init_browse (char *path, struct browser_state *state)
   char buf[LONG_STRING];
   char nsbuf[LONG_STRING];
   char mbox[LONG_STRING];
-  char host[SHORT_STRING];
-  int port;
   char list_cmd[5];
   char seq[16];
-  char *ipath = NULL;
   IMAP_NAMESPACE_INFO nsi[16];
   int home_namespace = 0;
   int n;
@@ -59,8 +56,9 @@ int imap_init_browse (char *path, struct browser_state *state)
   short showparents = 0;
   int noselect;
   int noinferiors;
+  IMAP_MBOX mx;
 
-  if (imap_parse_path (path, host, sizeof (host), &port, &ipath))
+  if (imap_parse_path (path, &mx))
   {
     mutt_error ("%s is an invalid IMAP path", path);
     return -1;
@@ -68,7 +66,7 @@ int imap_init_browse (char *path, struct browser_state *state)
 
   strfcpy (list_cmd, option (OPTIMAPLSUB) ? "LSUB" : "LIST", sizeof (list_cmd));
 
-  conn = mutt_socket_select_connection (host, port, 0);
+  conn = mutt_socket_select_connection (&mx, 0);
   idata = CONN_DATA;
 
   if (!idata || (idata->state == IMAP_DISCONNECTED))
@@ -84,11 +82,11 @@ int imap_init_browse (char *path, struct browser_state *state)
       return (-1);
   }
 
-  if (ipath[0] == '\0')
+  if (mx.mbox[0] == '\0')
   {
     home_namespace = 1;
     mbox[0] = 0;		/* Do not replace "" with "INBOX" here */
-    ipath = ImapHomeNamespace;
+    mx.mbox = ImapHomeNamespace;
     nns = 0;
     if (mutt_bit_isset(idata->capabilities,NAMESPACE))
     {
@@ -98,13 +96,13 @@ int imap_init_browse (char *path, struct browser_state *state)
       if (verify_namespace (conn, nsi, nns) != 0)
 	return (-1);
     }
-    if (!ipath)		/* Any explicitly set imap_home_namespace wins */
+    if (!mx.mbox)		/* Any explicitly set imap_home_namespace wins */
     { 
       for (i = 0; i < nns; i++)
 	if (nsi[i].listable &&
 	    (nsi[i].type == IMAP_NS_PERSONAL || nsi[i].type == IMAP_NS_SHARED))
 	{
-	  ipath = nsi->prefix;
+	  mx.mbox = nsi->prefix;
 	  nsi->home_namespace = 1;
 	  break;
 	}
@@ -113,9 +111,9 @@ int imap_init_browse (char *path, struct browser_state *state)
 
   mutt_message _("Contacted server, getting folder list...");
 
-  if (ipath && ipath[0] != '\0')
+  if (mx.mbox && mx.mbox[0] != '\0')
   {
-    imap_fix_path (idata, ipath, mbox, sizeof (mbox));
+    imap_fix_path (idata, mx.mbox, mbox, sizeof (mbox));
     n = mutt_strlen (mbox);
 
     dprint (3, (debugfile, "imap_init_browse: mbox: %s\n", mbox));
@@ -153,7 +151,7 @@ int imap_init_browse (char *path, struct browser_state *state)
     if (mbox[n-1] == idata->delim)
     {
       showparents = 1;
-      imap_qualify_path (buf, sizeof (buf), host, port, mbox, NULL);
+      imap_qualify_path (buf, sizeof (buf), &mx, mbox, NULL);
       state->folder = safe_strdup (buf);
       n--;
     }
@@ -182,7 +180,7 @@ int imap_init_browse (char *path, struct browser_state *state)
         mbox[n++] = ctmp;
         ctmp = mbox[n];
         mbox[n] = '\0';
-        imap_qualify_path (buf, sizeof (buf), host, port, mbox, NULL);
+        imap_qualify_path (buf, sizeof (buf), &mx, mbox, NULL);
         state->folder = safe_strdup (buf);
       }
       mbox[n] = ctmp;
@@ -197,7 +195,7 @@ int imap_init_browse (char *path, struct browser_state *state)
         imap_add_folder (idata->delim, relpath, 1, 0, state, 1); 
       if (!state->folder)
       {
-        imap_qualify_path (buf, sizeof (buf), host, port, relpath, NULL);
+        imap_qualify_path (buf, sizeof (buf), &mx, relpath, NULL);
         state->folder = safe_strdup (buf);
       }
     }
@@ -206,7 +204,7 @@ int imap_init_browse (char *path, struct browser_state *state)
   /* no namespace, no folder: set folder to host only */
   if (!state->folder)
   {
-    imap_qualify_path (buf, sizeof (buf), host, port, NULL, NULL);
+    imap_qualify_path (buf, sizeof (buf), &mx, NULL, NULL);
     state->folder = safe_strdup (buf);
   }
 
@@ -248,14 +246,12 @@ static int add_list_result (CONNECTION *conn, const char *seq, const char *cmd,
 {
   IMAP_DATA *idata = CONN_DATA;
   char buf[LONG_STRING];
-  char host[SHORT_STRING];
-  int port;
-  char *curfolder;
   char *name;
   int noselect;
   int noinferiors;
+  IMAP_MBOX mx;
 
-  if (imap_parse_path (state->folder, host, sizeof (host), &port, &curfolder))
+  if (imap_parse_path (state->folder, &mx))
   {
     dprint (2, (debugfile,
       "add_list_result: current folder %s makes no sense\n", state->folder));
@@ -277,7 +273,7 @@ static int add_list_result (CONNECTION *conn, const char *seq, const char *cmd,
       if (isparent)
         noselect = 1;
       /* prune current folder from output */
-      if (isparent || strncmp (name, curfolder, strlen (name)))
+      if (isparent || strncmp (name, mx.mbox, strlen (name)))
         imap_add_folder (idata->delim, name, noselect, noinferiors, state,
           isparent);
     }
@@ -287,31 +283,23 @@ static int add_list_result (CONNECTION *conn, const char *seq, const char *cmd,
 }
 
 /* imap_add_folder: add a folder name to the browser list, formatting it as
- *   necessary. NOTE: check for duplicate folders removed, believed to be
- *   useless. Tell me if otherwise (brendan@kublai.com) */
+ *   necessary. */
 static void imap_add_folder (char delim, char *folder, int noselect,
   int noinferiors, struct browser_state *state, short isparent)
 {
   char tmp[LONG_STRING];
   char relpath[LONG_STRING];
-  char host[SHORT_STRING];
-  int port;
-  char *curfolder;
-  int flen = strlen (folder);
+  IMAP_MBOX mx;
 
-  if (imap_parse_path (state->folder, host, sizeof (host), &port, &curfolder))
+  if (imap_parse_path (state->folder, &mx))
     return;
 
   imap_unquote_string (folder);
 
-  /* plus 2: folder may be selectable AND have inferiors */
-  if (state->entrylen + 2 == state->entrymax)
+  if (state->entrylen + 1 == state->entrymax)
   {
     safe_realloc ((void **) &state->entry,
       sizeof (struct folder_file) * (state->entrymax += 256));
-    /* apparently linux+glibc2.1 was zeroing this for me? Jon Hellan reports
-     * that the browser segfaults on more than 256 entries. I never had this
-     * problem */
     memset (state->entry + state->entrylen, 0,
       (sizeof (struct folder_file) * (state->entrymax - state->entrylen)));
   }
@@ -320,8 +308,8 @@ static void imap_add_folder (char delim, char *folder, int noselect,
   if (isparent)
     strfcpy (relpath, "../", sizeof (relpath));
   /* strip current folder from target, to render a relative path */
-  else if (!strncmp (curfolder, folder, strlen (curfolder)))
-    strfcpy (relpath, folder + strlen (curfolder), sizeof (relpath));
+  else if (!strncmp (mx.mbox, folder, strlen (mx.mbox)))
+    strfcpy (relpath, folder + strlen (mx.mbox), sizeof (relpath));
   else
     strfcpy (relpath, folder, sizeof (relpath));
 
@@ -331,34 +319,19 @@ static void imap_add_folder (char delim, char *folder, int noselect,
   if (!((regexec (Mask.rx, relpath, 0, NULL, 0) == 0) ^ Mask.not))
     return;
 
-  if (!noselect)
-  {
-    imap_qualify_path (tmp, sizeof (tmp), host, port, folder, NULL);
-    (state->entry)[state->entrylen].name = safe_strdup (tmp);
+  imap_qualify_path (tmp, sizeof (tmp), &mx, folder, NULL);
+  (state->entry)[state->entrylen].name = safe_strdup (tmp);
 
-    (state->entry)[state->entrylen].desc = safe_strdup (relpath);
+  (state->entry)[state->entrylen].desc = safe_strdup (relpath);
 
-    (state->entry)[state->entrylen].notfolder = 0;
-    (state->entrylen)++;
-  }
-  if (!noinferiors)
-  {
-    char trailing_delim[2];
-
-    /* create trailing delimiter if necessary */
-    trailing_delim[1] = '\0';
-    trailing_delim[0] = (flen && folder[flen - 1] != delim) ? delim : '\0';
-
-    imap_qualify_path (tmp, sizeof (tmp), host, port, folder, trailing_delim);
-    (state->entry)[state->entrylen].name = safe_strdup (tmp);
-
-    if (!isparent && (strlen (relpath) < sizeof (relpath) - 2))
-      strcat (relpath, trailing_delim);
-    (state->entry)[state->entrylen].desc = safe_strdup (relpath);
-
-    (state->entry)[state->entrylen].notfolder = 1;
-    (state->entrylen)++;
-  }
+  (state->entry)[state->entrylen].imap = 1;
+  /* delimiter at the root is useless. */
+  if (folder[0] == '\0')
+    delim = '\0';
+  (state->entry)[state->entrylen].delim = delim;
+  (state->entry)[state->entrylen].selectable = !noselect;
+  (state->entry)[state->entrylen].inferiors = !noinferiors;
+  (state->entrylen)++;
 }
 
 static int compare_names(struct folder_file *a, struct folder_file *b) 
@@ -388,9 +361,7 @@ static int get_namespace (IMAP_DATA *idata, char *nsbuf, int nsblen,
   do 
   {
     if (mutt_socket_read_line_d (buf, sizeof (buf), idata->conn) < 0)
-    {
-      return (-1);
-    }
+      return -1;
 
     if (buf[0] == '*') 
     {
@@ -465,7 +436,7 @@ static int get_namespace (IMAP_DATA *idata, char *nsbuf, int nsblen,
   return 0;
 }
 
-/* Check which namespaces actually exist */
+/* Check which namespaces have contents */
 static int verify_namespace (CONNECTION *conn, IMAP_NAMESPACE_INFO *nsi, 
   int nns)
 {
@@ -478,8 +449,11 @@ static int verify_namespace (CONNECTION *conn, IMAP_NAMESPACE_INFO *nsi,
   for (i = 0; i < nns; i++, nsi++)
   {
     imap_make_sequence (seq, sizeof (seq));
-    snprintf (buf, sizeof (buf), "%s %s \"\" \"%s\"\r\n", seq, 
-	      option (OPTIMAPLSUB) ? "LSUB" : "LIST", nsi->prefix);
+    /* Cyrus gives back nothing if the % isn't added. This may return lots
+     * of data in some cases, I guess, but I currently feel that's better
+     * than invisible namespaces */
+    snprintf (buf, sizeof (buf), "%s %s \"\" \"%s%c%%\"\r\n", seq, 
+	      option (OPTIMAPLSUB) ? "LSUB" : "LIST", nsi->prefix, nsi->delim);
     mutt_socket_write (conn, buf);
 
     nsi->listable = 0;
@@ -487,9 +461,8 @@ static int verify_namespace (CONNECTION *conn, IMAP_NAMESPACE_INFO *nsi,
     do 
     {
       if (imap_parse_list_response(conn, buf, sizeof(buf), &name,
-				   &(nsi->noselect), &(nsi->noinferiors), 
-				   &delim) != 0)
-	return (-1);
+          &(nsi->noselect), &(nsi->noinferiors), &delim) != 0)
+	return -1;
       nsi->listable |= (name != NULL);
     }
     while ((mutt_strncmp (buf, seq, SEQLEN) != 0));
