@@ -25,12 +25,19 @@
 
 /* -- symbols -- */
 #define IMAP_PORT 143
+#define IMAP_SSL_PORT 993
 
 /* number of entries in the hash table */
 #define IMAP_CACHE_LEN 10
 
 #define SEQLEN 5
 
+#define M_IMAP_USER (1<<0)
+#define M_IMAP_PORT (1<<1)
+#define M_IMAP_TYPE (1<<2)
+#define M_IMAP_PASS (1<<3)
+#define M_IMAP_CRAM (1<<4)
+
 enum
 {
   IMAP_FATAL = 1,
@@ -148,7 +155,6 @@ typedef struct
 
 /* -- private IMAP functions -- */
 /* imap.c */
-int imap_create_mailbox (IMAP_DATA* idata, char* mailbox);
 int imap_make_msg_set (char* buf, size_t buflen, CONTEXT* ctx, int flag,
   int changed);
 int imap_open_connection (IMAP_DATA* idata, CONNECTION* conn);
