@@ -24,7 +24,7 @@
 #include "keymap.h"
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 #include "pgp.h"
 #endif
 
@@ -1129,7 +1129,7 @@ static int parse_set (BUFFER *tmp, BUFFER *s, unsigned long data, BUFFER *err)
 	case DT_SORT_BROWSER:
 	  map = SortBrowserMethods;
 	  break;
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 	case DT_SORT_KEYS:
 	  map = SortKeyMethods;
 	  break;
@@ -1535,7 +1535,7 @@ int mutt_var_value_complete (char *buffer, size_t len, int pos)
 	  case DT_SORT_BROWSER:
 	    map = SortBrowserMethods;
 	    break;
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
 	  case DT_SORT_KEYS:
 	    map = SortKeyMethods;
 	    break;
@@ -1873,3 +1873,13 @@ void mutt_init (int skip_sys_rc, LIST *commands)
   set_option (OPTWEED); /* turn weeding on by default */
 #endif
 }
+
+int mutt_get_hook_type (const char *name)
+{
+  struct command_t *c;
+
+  for (c = Commands ; c->name ; c++)
+    if (c->func == mutt_parse_hook && mutt_strcasecmp (c->name, name) == 0)
+      return c->data;
+  return 0;
+}
