@@ -39,7 +39,7 @@ struct mapping_t Menus[] = {
  { "postpone",	MENU_POST },
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
  { "pgp",	MENU_PGP },
 #endif  
   
@@ -529,7 +529,7 @@ void km_init (void)
 
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
   create_bindings (OpPgp, MENU_PGP);
 #endif
 
@@ -588,8 +588,8 @@ void km_init (void)
 
   km_bindkey ("<enter>", MENU_MAIN, OP_DISPLAY_MESSAGE);
 
-  km_bindkey ("x", MENU_PAGER, OP_PAGER_EXIT);
-  km_bindkey ("q", MENU_PAGER, OP_PAGER_EXIT);
+  km_bindkey ("x", MENU_PAGER, OP_EXIT);
+  km_bindkey ("i", MENU_PAGER, OP_EXIT);
   km_bindkey ("<backspace>", MENU_PAGER, OP_PREV_LINE);
   km_bindkey ("<pagedown>", MENU_PAGER, OP_NEXT_PAGE);
   km_bindkey ("<pageup>", MENU_PAGER, OP_PREV_PAGE);
@@ -739,7 +739,7 @@ struct binding_t *km_get_table (int menu)
 
 
 
-#ifdef _PGPPATH
+#ifdef HAVE_PGP
     case MENU_PGP:
       return OpPgp;
 #endif
